==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/igx-spline-fragment-base-component.js <==
import { __extends } from "tslib";
import { Component } from '@angular/core';
import { IgxSplineSeriesBaseComponent } from "./igx-spline-series-base-component";
import { toPoint, fromPoint } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents one part in a StackedSplineSeries or StackedSplineAreaSeries.
*/
var IgxSplineFragmentBaseComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgxSplineFragmentBaseComponent, _super);
    function IgxSplineFragmentBaseComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxSplineFragmentBaseComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxSplineFragmentBaseComponent.prototype, "isFragment", {
        /**
         * Gets whether the current series is a stack fragment.
        */
        get: function () {
            return this.i.dx;
        },
        enumerable: false,
        configurable: true
    });
    IgxSplineFragmentBaseComponent.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ps(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgxSplineFragmentBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxSplineFragmentBaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxSplineFragmentBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxSplineFragmentBaseComponent, selector: "ng-component", usesInheritance: true, ngImport: i0, template: "", isInline: true });
    return IgxSplineFragmentBaseComponent;
}(IgxSplineSeriesBaseComponent));
export { IgxSplineFragmentBaseComponent };
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxSplineFragmentBaseComponent, decorators: [{
            type: Component,
            args: [{
                    template: "",
                }]
        }], ctorParameters: function () { return []; } });

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/igx-spline-fragment-base-component.js <==
import { __extends } from "tslib";
import { Component } from '@angular/core';
import { IgxSplineSeriesBaseComponent } from "./igx-spline-series-base-component";
import { toPoint, fromPoint } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents one part in a StackedSplineSeries or StackedSplineAreaSeries.
*/
var IgxSplineFragmentBaseComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgxSplineFragmentBaseComponent, _super);
    function IgxSplineFragmentBaseComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxSplineFragmentBaseComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxSplineFragmentBaseComponent.prototype, "isFragment", {
        /**
         * Gets whether the current series is a stack fragment.
        */
        get: function () {
            return this.i.ep;
        },
        enumerable: false,
        configurable: true
    });
    IgxSplineFragmentBaseComponent.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.th(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgxSplineFragmentBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxSplineFragmentBaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxSplineFragmentBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxSplineFragmentBaseComponent, selector: "ng-component", usesInheritance: true, ngImport: i0, template: "", isInline: true });
    return IgxSplineFragmentBaseComponent;
}(IgxSplineSeriesBaseComponent));
export { IgxSplineFragmentBaseComponent };
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxSplineFragmentBaseComponent, decorators: [{
            type: Component,
            args: [{
                    template: "",
                }]
        }], ctorParameters: function () { return []; } });
